[![codecov](https://codecov.io/gh/buettnerlab/pytometry/branch/main/graph/badge.svg?token=AEG5ra92HV)](https://codecov.io/gh/buettnerlab/pytometry)
[![Stars](https://img.shields.io/github/stars/buettnerlab/pytometry?logo=GitHub&color=yellow)](https://github.com/buettnerlab/pytometry/stargazers)
<a href="https://gitmoji.dev">
<img src="https://img.shields.io/badge/gitmoji-%20😜%20😍-FFDD67.svg?style=flat-square" alt="Gitmoji">
</a>

# Pytometry: Flow & mass cytometry analytics

This package is in private beta at this moment!

This package extends scanpy to for efficient and scalable handling of flow and mass cytometry data analysis. It provides

- the functionality to read in flow data in the fcs file format as anndata objects
- flow and mass cytometry specific preprocessing tools
- access to the entire scanpy workflow functionality

Follow https://twitter.com/mbuttner to learn about a first public release.

For beta users: Read the [docs](https://pytometry.netlify.app).
